from flask import request, after_this_request
from flask_restplus import Namespace, fields, Resource
from pyrest.utils.taskmap.Taskmap import MapFactory
import json

taskmap_api = Namespace('taskmap', description='Operations for taskmaps')

from pyrest.models.taskmap import taskmap_model, geometry_model


# Base taskmap service
@taskmap_api.route('/')
class TaskmapBaseService(Resource):
    def get(self):
        return "<h1>Welcome to the taskmaps API</h1>"

# Taskmap creation service
@taskmap_api.route('/generate/<type>')
@taskmap_api.param('type', 'Type of taskmap to create')
class TaskmapCreationService(Resource):
    @taskmap_api.expect(taskmap_model)
    @taskmap_api.doc('Create a taskmap based on the GeoJSON data provided.')
    def post(self, type):
        data = request.get_json(force=True)

        jsondata = data
        taskmap = MapFactory.factory(jsondata, type)

        return taskmap


# Taskmap creation service
@taskmap_api.route('/list')
class TaskmapCreationService(Resource):
    @taskmap_api.expect(geometry_model)
    @taskmap_api.doc('Get a list of all available tasksmap based on a given GeoJSON geometry.')
    def post(self):
        data = request.get_json(force=True)
        return MapFactory.getAvailableTypes(data)